@@ -14,7 +14,6 @@
 
 #define XC_LDA_C_RPA  3   /* Random Phase Approximation   */
 
-#include "decl_lda.h"
 #include "maple2c/lda_exc/lda_c_rpa.c"
 #include "work_lda.c"
 
@@ -31,5 +30,5 @@ const xc_func_info_type xc_func_info_lda_c_rpa = {
   1e-32,
   {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  work_lda, NULL, NULL
+  &work_lda, NULL, NULL
 };
