@@ -49,5 +49,5 @@ const xc_func_info_type xc_func_info_mgga_c_r2scanl = {
   1e-15,
   {N_PAR, names, desc, par_r2scanl, r2scanl_set_ext_params},
   mgga_c_r2scanl_init, NULL,
-  NULL, NULL, xc_deorbitalize_func
+  NULL, NULL, &xc_deorbitalize_func
 };
